Class: MasterView::Directives::Global_inline_erb
- Inherits:
-
MasterView::DirectiveBase
- Object
- MasterView::DirectiveBase
- MasterView::Directives::Global_inline_erb
- Defined in:
- lib/masterview/directives/global_inline_erb.rb
Overview
outputs a block around the text tags, if left bracket count is higher than right assume that the end is a right bracket otherwise use end
Constant Summary
Constants included from MasterView::DirectiveHelpers
MasterView::DirectiveHelpers::CRLF, MasterView::DirectiveHelpers::ERB_END, MasterView::DirectiveHelpers::ERB_EVAL, MasterView::DirectiveHelpers::ERB_START
Instance Method Summary collapse
- #characters(dcs) ⇒ Object
- #global_directive? ⇒ Boolean
-
#initialize(attribute_value = nil) ⇒ Global_inline_erb
constructor
A new instance of Global_inline_erb.
- #priority ⇒ Object
- #stag(dcs) ⇒ Object
Methods inherited from MasterView::DirectiveBase
#append_to_attr_value!, #attr_lckv_matches, #attr_value, #attr_value=, #attrs, #attrs=, #attrs_lck, #attrs_lckv, #common_html_options, #content, #content=, #content_str, #data, #data=, #erb, #erb_content, full_attr_name, #merge_hash_attr_value!, #parse_attr_value, #prepend_to_attr_value!, #quote, register_directive, #remove_strings_from_attr_value!, #save_directive_call_stack, #tag_name, #tag_name=
Methods included from MasterView::DirectiveHelpers
#delete_last_in_parent, #find_last_in_parent, #find_string_val_in_string_hash, #lowercase_attribute_keys, #lowercase_attribute_keys_and_values, #merge_into_embedded_hash, #parse, #parse_eval_into_array, #parse_eval_into_hash, #remove_prepended_strings
Methods included from PluginLoadTracking
Constructor Details
#initialize(attribute_value = nil) ⇒ Global_inline_erb
Returns a new instance of Global_inline_erb.
7 8 9 |
# File 'lib/masterview/directives/global_inline_erb.rb', line 7 def initialize(attribute_value = nil) super(attribute_value) end |
Instance Method Details
#characters(dcs) ⇒ Object
26 27 28 29 |
# File 'lib/masterview/directives/global_inline_erb.rb', line 26 def characters(dcs) replace_with_erb!( data ) dcs.render end |
#global_directive? ⇒ Boolean
15 16 17 |
# File 'lib/masterview/directives/global_inline_erb.rb', line 15 def global_directive? true end |
#priority ⇒ Object
11 12 13 |
# File 'lib/masterview/directives/global_inline_erb.rb', line 11 def priority DirectivePriorities::Low end |
#stag(dcs) ⇒ Object
19 20 21 22 23 24 |
# File 'lib/masterview/directives/global_inline_erb.rb', line 19 def stag(dcs) attrs.each do |key, value| replace_with_erb!( value ) end dcs.render end |